==> fetch.php?media=uls%3Auls_update-1.9.5.tgz: update/von_1.9.4/sql/regcount.sql <==
set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS regcount//
create function regcount(wid integer, reg varchar(1024), back varchar(10))
                          returns varchar(30)
  deterministic
  sql security invoker
  begin
    declare wt varchar(30);
    declare anz integer;
    declare vondat datetime(6);

    set anz = back + 0;
    case right(back, 1)
      when 'm' then
        set vondat = now() - interval anz minute;
      when 'h' then
        set vondat = now() - interval anz hour;
      when 'd' then
        set vondat = now() - interval anz day;
      else
        set vondat = now() - interval anz minute;
    end case;
    select wtab from werteindizes, teststepdetails, einheiten
      where werteindizes.ID=wid and teststepdetailsID=teststepdetails.ID
        and einheitID=einheiten.ID
      into wt;
    case wt
      when 'swerte' then
        return (select count(*) from swerte
                where werteindizesID=wid and datum >= vondat and wert regexp reg);
      when 'twerte' then
        return (select count(*) from twerte
                where werteindizesID=wid and datum >= vondat and wert regexp reg);
      when 'cwerte' then
        return (select count(*) from cwerte
                where werteindizesID=wid and datum >= vondat and wert regexp reg);
      when 'pwerte' then
        return (select count(*) from pwerte
                where werteindizesID=wid and datum >= vondat and wert regexp reg);
      else
        return (select count(*) from zwerte
                where werteindizesID=wid and datum >= vondat and wert regexp reg);
    end case;
end//

GRANT EXECUTE on FUNCTION regcount to logginglesen@'localhost', loggingtest@'localhost'//

==> fetch.php?media=uls%3Auls_update-1.9.6.tgz: update/von_1.9.5/sql/regcount.sql <==
-- regcount.sql
--
-- function regcount(wid, reg, back) returns varchar
-- wid: werteindizesID
-- reg: regular expression
-- back: <n>[mhd] - <n> minutes / <n> hours / <n> days
-- return: number of vales that match reg in the last "back"

set @@character_set_client = 'utf8';

delimiter //

DROP FUNCTION IF EXISTS regcount//
create function regcount(wid integer, reg varchar(1024), back varchar(10))
                          returns varchar(30)
  deterministic
  sql security invoker
  begin
    declare wt varchar(30);
    declare anz integer;
    declare vondat datetime(6);

    set anz = back + 0;
    case right(back, 1)
      when 'm' then
        set vondat = now() - interval anz minute;
      when 'h' then
        set vondat = now() - interval anz hour;
      when 'd' then
        set vondat = now() - interval anz day;
      else
        set vondat = now() - interval anz minute;
    end case;
    select wtab into wt from werteindizes join teststepdetails on teststepdetails.ID = teststepdetailsID join einheiten on einheiten.ID = einheitID
      where werteindizes.ID=wid;
    case wt
      when 'swerte' then
        return (select count(*) from swerte
                where werteindizesID=wid and datum >= vondat and wert regexp reg);
      when 'twerte' then
        return (select count(*) from twerte
                where werteindizesID=wid and datum >= vondat and wert regexp reg);
      when 'cwerte' then
        return (select count(*) from cwerte
                where werteindizesID=wid and datum >= vondat and wert regexp reg);
      when 'pwerte' then
        return (select count(*) from pwerte
                where werteindizesID=wid and datum >= vondat and wert regexp reg);
      else
        return (select count(*) from zwerte
                where werteindizesID=wid and datum >= vondat and wert regexp reg);
    end case;
end//

GRANT EXECUTE on FUNCTION regcount to logginglesen@'localhost', loggingtest@'localhost'//
